package ru.dbotthepony.mc.otm.datagen.advancements

import net.minecraft.advancements.Advancement
import net.minecraft.advancements.RequirementsStrategy
import net.minecraft.advancements.critereon.InventoryChangeTrigger
import net.minecraft.world.item.ItemStack
import net.minecraftforge.common.data.ExistingFileHelper
import ru.dbotthepony.mc.otm.core.TranslatableComponent
import ru.dbotthepony.mc.otm.datagen.lang.MatteryLanguageProvider
import ru.dbotthepony.mc.otm.datagen.modLocation
import ru.dbotthepony.mc.otm.registry.MItemTags
import ru.dbotthepony.mc.otm.registry.MItems
import ru.dbotthepony.mc.otm.triggers.BlackHoleTrigger
import java.util.function.Consumer

fun addAdvancements(serializer: Consumer<Advancement>, existingFileHelper: ExistingFileHelper, lang: MatteryLanguageProvider) {
	val translation = lang.english.Prepended("otm.advancements.regular")

	val root = AdvancementBuilder()
		.requirements(RequirementsStrategy.OR)
		.display(
			itemStack = ItemStack(MItems.TRITANIUM_INGOT),
			title = TranslatableComponent(translation.add("root", "Overdrive That Matters")),
			description = TranslatableComponent(translation.add("root.desc", "Its all about things that matter")),
			showToast = false,
			announceChat = false,
			background = modLocation("textures/block/decorative/tritanium_block_gray.png")
		)
		.addCriterion("has_tritanium_ore", criterion(MItemTags.TRITANIUM_ORES))
		.addCriterion("has_tritanium_ore_clump", criterion(MItemTags.TRITANIUM_ORE_CLUMPS))
		.addCriterion("has_tritanium_ingot", InventoryChangeTrigger.TriggerInstance.hasItems(MItems.TRITANIUM_INGOT))
		.save(serializer, modLocation("regular/root"), existingFileHelper)

	AdvancementBuilder()
		.parent(root)
		.display(
			itemStack = ItemStack(MItems.BLACK_HOLE),
			title = TranslatableComponent(translation.add("black_hole_pull", "Something Massive and Something Close")),
			description = TranslatableComponent(translation.add("black_hole_pull.desc", "Experience Singularity's gravitational force, better not to get closer")),
		)
		.addCriterion("pulled_by_black_hole", BlackHoleTrigger.Instance)
		.save(serializer, modLocation("regular/black_hole"), existingFileHelper)
}
